@@ -33,9 +33,13 @@ huber_loss_pseudo <- new_numeric_metric(
 
 #' @rdname huber_loss_pseudo
 #' @export
-huber_loss_pseudo.data.frame <- function(data, truth, estimate,
-                                         delta = 1, na_rm = TRUE, ...) {
-
+huber_loss_pseudo.data.frame <- function(data,
+                                         truth,
+                                         estimate,
+                                         delta = 1,
+                                         na_rm = TRUE,
+                                         case_weights = NULL,
+                                         ...) {
   metric_summarizer(
     metric_nm = "huber_loss_pseudo",
     metric_fn = huber_loss_pseudo_vec,
@@ -43,39 +47,47 @@ huber_loss_pseudo.data.frame <- function(data, truth, estimate,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
     na_rm = na_rm,
+    case_weights = !!enquo(case_weights),
     # Extra argument for huber_loss_pseudo_impl()
     metric_fn_options = list(delta = delta)
   )
-
 }
 
 #' @export
 #' @rdname huber_loss_pseudo
-huber_loss_pseudo_vec <- function(truth, estimate,
-                                  delta = 1, na_rm = TRUE, ...) {
-
-  huber_loss_pseudo_impl <- function(truth, estimate, delta) {
-
-    if (!rlang::is_bare_numeric(delta, n = 1L)) {
-      abort("`delta` must be a single numeric value.")
-    }
-
-    if (!(delta >= 0)) {
-      abort("`delta` must be a positive value.")
-    }
-
-    a <- truth - estimate
-    mean(delta^2 * (sqrt(1 + (a / delta)^2) - 1))
-
-  }
-
+huber_loss_pseudo_vec <- function(truth,
+                                  estimate,
+                                  delta = 1,
+                                  na_rm = TRUE,
+                                  case_weights = NULL,
+                                  ...) {
   metric_vec_template(
     metric_impl = huber_loss_pseudo_impl,
     truth = truth,
     estimate = estimate,
     na_rm = na_rm,
+    case_weights = case_weights,
     cls = "numeric",
     delta = delta
   )
+}
 
+huber_loss_pseudo_impl <- function(truth,
+                                   estimate,
+                                   ...,
+                                   delta = 1,
+                                   case_weights = NULL) {
+  check_dots_empty()
+
+  if (!rlang::is_bare_numeric(delta, n = 1L)) {
+    abort("`delta` must be a single numeric value.")
+  }
+  if (!(delta >= 0)) {
+    abort("`delta` must be a positive value.")
+  }
+
+  a <- truth - estimate
+  loss <- delta^2 * (sqrt(1 + (a / delta)^2) - 1)
+
+  yardstick_mean(loss, case_weights = case_weights)
 }
