@@ -35,36 +35,51 @@ rpiq <- new_numeric_metric(
 
 #' @rdname rpiq
 #' @export
-rpiq.data.frame <- function(data, truth, estimate, na_rm = TRUE, ...) {
-
+rpiq.data.frame <- function(data,
+                            truth,
+                            estimate,
+                            na_rm = TRUE,
+                            case_weights = NULL,
+                            ...) {
   metric_summarizer(
     metric_nm = "rpiq",
     metric_fn = rpiq_vec,
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
-    na_rm = na_rm
+    na_rm = na_rm,
+    case_weights = !!enquo(case_weights)
   )
-
 }
 
 #' @export
 #' @rdname rpiq
-#' @importFrom stats IQR
-rpiq_vec <- function(truth, estimate, na_rm = TRUE, ...) {
-
-  rpiq_impl <- function(truth, estimate) {
-
-    IQR(truth) / rmse_vec(truth, estimate)
-
-  }
-
+rpiq_vec <- function(truth,
+                     estimate,
+                     na_rm = TRUE,
+                     case_weights = NULL,
+                     ...) {
   metric_vec_template(
     metric_impl = rpiq_impl,
     truth = truth,
     estimate = estimate,
     na_rm = na_rm,
+    case_weights = case_weights,
     cls = "numeric"
   )
+}
 
+rpiq_impl <- function(truth, estimate, ..., case_weights = NULL) {
+  check_dots_empty()
+
+  quantiles <- yardstick_quantile(
+    x = truth,
+    probabilities = c(0.25, 0.75),
+    case_weights = case_weights
+  )
+
+  iqr <- quantiles[[2L]] - quantiles[[1L]]
+  rmse <- rmse_vec(truth, estimate, case_weights = case_weights)
+
+  iqr / rmse
 }
